@@ -1,6 +1,8 @@
 """
 SCRUD-Django - Semantic Create, Read, Update and Delete Django application.
 """
+
+__version__ = "0.1.9"
 import base64
 import datetime
 
@@ -38,3 +40,7 @@ class ScrudServices:
 
 
 services = ScrudServices()
+
+
+def collection_type_uri_for(type_uri):
+    return f"https://api.openteams.com/json-schema/ResourceCollection?contents_type={type_uri}"  # noqa: E501
