@@ -1,4 +1,3 @@
-import importlib.resources
 import json
 import logging
 from datetime import datetime
@@ -24,13 +23,11 @@ class ResourceTypeRegistration:
         resource_type_uri: str,
         revision: str,
         schema_resource: Resource = None,
-        schema_func: callable = None,
+        schema_func: str = None,
         schema_uri: str = None,
         context_resource: Resource = None,
-        context_func: callable = None,
+        context_func: str = None,
         context_uri: str = None,
-        indexing_policy_resource: Resource = None,
-        indexing_policy_func: callable = None,
         slug: str = None,
     ):
         """
@@ -56,23 +53,10 @@ class ResourceTypeRegistration:
                 self.resource_type.schema = register_json_schema(
                     schema_func, self.resource_type.schema
                 )
-            else:
-                self.resource_type.schema = schema_resource
-
             if context_resource is None and context_func:
                 self.resource_type.context = register_json_ld_context(
                     context_func, self.resource_type.context
                 )
-            else:
-                self.resource_type.context = context_resource
-
-            if indexing_policy_resource is None and indexing_policy_func:
-                self.resource_type.indexing_policy = register_indexing_policy(
-                    indexing_policy_func, self.resource_type.indexing_policy
-                )
-            else:
-                self.resource_type.indexing_policy = indexing_policy_resource
-
             self.resource_type.save()
 
         # Register with service catalog
@@ -218,8 +202,6 @@ JSON_SCHEMA_REGISTRATION_ = None
 JSON_SCHEMA_RESOURCE_TYPE_ = None
 JSON_LD_RESOURCE_TYPE_ = None
 JSON_LD_REGISTRATION_ = None
-INDEXING_POLICY_RESOURCE_TYPE_ = None
-INDEXING_POLICY_REGISTRATION_ = None
 
 
 def register_json_schema_resource_type():
@@ -249,25 +231,6 @@ def register_json_ld_resource_type():
     return JSON_LD_RESOURCE_TYPE_
 
 
-def register_indexing_policy_resource_type():
-    global INDEXING_POLICY_RESOURCE_TYPE_
-    global INDEXING_POLICY_REGISTRATION_
-    if INDEXING_POLICY_RESOURCE_TYPE_ is None:
-        INDEXING_POLICY_REGISTRATION_ = ResourceTypeRegistration(
-            resource_type_uri="http://api.openteams.com/json-ld/IndexingPolicy",
-            revision="1",
-            slug="indexing-policies",
-            schema_func=lambda: importlib.resources.read_text(
-                "scrud_django.static", "IndexingPolicy-schema.json"
-            ),
-            context_func=lambda: importlib.resources.read_text(
-                "scrud_django.static", "IndexingPolicy-ld.json"
-            ),
-        )
-        INDEXING_POLICY_RESOURCE_TYPE_ = INDEXING_POLICY_REGISTRATION_.resource_type
-    return INDEXING_POLICY_RESOURCE_TYPE_
-
-
 def register_json_file(file_contents_func, previous_revision, resource_type):
     contents = file_contents_func()
     if type(contents) is str:
@@ -291,11 +254,6 @@ def register_json_ld_context(context_func, previous_revision):
     return register_json_file(context_func, previous_revision, resource_type)
 
 
-def register_indexing_policy(indexing_policy_func, previous_revision):
-    resource_type = register_indexing_policy_resource_type()
-    return register_json_file(indexing_policy_func, previous_revision, resource_type)
-
-
 def json_resource_type(
     resource_type_uri: str,
     revision: str,
@@ -306,8 +264,6 @@ def json_resource_type(
     context_resource: Resource = None,
     context_func=None,
     context_uri: str = None,
-    indexing_policy_resource: Resource = None,
-    indexing_policy_func=None,
 ):
     """Registration of a single json resource type. Callers **should** provide one and
     only one of `schema_resource, schema_path, schema_uri` as well as one and only  one
@@ -324,8 +280,6 @@ def json_resource_type(
             context_resource=context_resource,
             context_func=context_func,
             context_uri=context_uri,
-            indexing_policy_resource=indexing_policy_resource,
-            indexing_policy_func=indexing_policy_func,
         )
         return resource_type_registration.urls
     except (OperationalError, ProgrammingError):
